@@ -218,14 +218,14 @@ our (@ISA, @EXPORT, @EXPORT_OK, $VERSION);
 
 @EXPORT = qw($VERSION &saveInSilicoDef &init &getInSilicoDefFiles $DEF_FILENAME_ENV);
 @EXPORT_OK = ();
-$VERSION = "1.3.0";
+$VERSION = "1.3.1";
 
 our $DEF_FILENAME_ENV='INSILICOSPECTRO_DEFFILE';
 
 sub saveInSilicoDef{
   my $out=shift;
   $out=">$out" if ((defined $out) and not $out=~/^>/);
-  my $saver=(defined $out)?(new SelectSaver(InSilicoSpectro::Utils::io->getFD($out) or die "cannot open [$out]: $!")):\*STDOUT;
+  my $saver=(defined $out)?(new SelectSaver(InSilicoSpectro::Utils::io->getFD($out) or CORE::die "cannot open [$out]: $!")):\*STDOUT;
   print <<EOT;
 <inSilicoDefinitions>
   <elements/>
@@ -260,16 +260,18 @@ sub init{
     print STDERR "no default found, opening config file from Phenyx::Config::GlobalParam\n" if $InSilicoSpectro::Utils::io::VERBOSE;
     require Phenyx::Config::GlobalParam;
     Phenyx::Config::GlobalParam::readParam(undef, 1);
-    require Phenyx::Manage::User;
-    my $tmp=Phenyx::Manage::User->new(name=>'default')->getFile('insilicodef.xml');
+    my $tmp;
+    eval "
+      use Phenyx::Manage::User;
+      \$tmp=Phenyx::Manage::User->new(name=>'default')->getFile('insilicodef.xml');
+    " or confess "error during eval statmeent: $!";
     push @tmp, $tmp;
   }
   @tmp or croak "must provide at least one  file argument";
-  
+  #warn  "init from files(@tmp)";
   InSilicoSpectro::InSilico::ModRes::init(@tmp);
   InSilicoSpectro::InSilico::CleavEnzyme::init(@tmp);
   InSilicoSpectro::InSilico::MassCalculator::init(@tmp);
-
 }
 
 use File::Basename;
